;; Generated package description from mpdired.el  -*- no-byte-compile: t -*-
(define-package "mpdired" "1.0.20240311.161639" "A dired-like client for Music Player Daemon" '((emacs "29")) :commit "c2fb656038e779c010353ecce1623c4b935dbf69" :url "https://elpa.gnu.org/packages/mpdired.html" :authors '(("Manuel Giraud" . "manuel@ledu-giraud.fr")) :maintainer '("Manuel Giraud" . "manuel@ledu-giraud.fr") :keywords '("multimedia"))
